/// <reference path="../../../ext-6.0.2-classic.d.ts" />

Ext.define('LMSplaylistEditor.ux.PanelSearchCustom', {
	extend: 'Ext.panel.Panel',
	requires: ['LMSplaylistEditor.ux.PanelSearchCustomItem'],
	xtype: 'slim-searchfilter',
	alias: 'widget.slim-searchfilter',
	id: 'PanelSearchCustom',
	reference: 'panel_search_custom',
	controller: 'SlimSearchController',

	border: false,
	layout: {
		type: 'vbox',
		align: 'left',
		padding: 10
	},

	allSort: ['me.titlesort','me.year','me.primary_artist','me.album'],
	allConds: [],
	sortBy: 'me.titlesort',
	searchForTracks: true,
	
	initComponent: function() {
		this.tbar = [{
			xtype: 'splitbutton',
			id: 'tbar-split-addcond',
			text: 'Add condition',
			//icon: 'resources/images/add.png',
			iconCls: 'x-fa fa-plus-circle',
//			tooltip: "Add condition",
			menu: {
				items: [{
					text: 'Genre',
					id: 'panelsearchcustom-button-addcondgenre',
					iconCls: 'x-fa fa-music',
					listeners: {
						click: 'onCustomSearchAddCondGenre',
						scope: 'controller'
						}
					},{
					text: 'Artist',
					id: 'panelsearchcustom-button-addcondartist',
					iconCls: 'x-fa fa-user-secret',
					listeners: {
						click: 'onCustomSearchAddCondArtist',
						scope: 'controller'
						}
					},{
					text: 'Rating',
					id: 'panelsearchcustom-button-addcondrating',
					iconCls: 'x-fa fa-thumbs-up',
					listeners: {
						click: 'onCustomSearchAddCondRating',
						scope: 'controller'
						}
					},{
					text: 'Year',
					id: 'panelsearchcustom-button-addcondyear',
					iconCls: 'x-fa fa-calendar',
					listeners: {
						click: 'onCustomSearchAddCondYear',
						scope: 'controller'
						}
					}]
				}
			},{
				xtype: 'cycle',
				showText: true,
				prependText: 'Search for: ',
				icon: 'resources/images/music.png',
				menu: {
					items: [{
						text: 'Tracks',
						checked: true
						},{
						text: 'Albums'
						}]
				},
				changeHandler: function(cycleBtn, activeItem) {
					this.searchForTracks = (activeItem.itemIndex ==0);
					cycleBtn.setIcon( (this.searchForTracks)?'resources/images/music.png':'resources/images/cd.png');
				},
				scope: this
			},{ 
				xtype: 'tbseparator' 
			},{
				xtype: 'button',
				id: 'panelsearchcustom-button-custsearch',
				iconCls: 'x-fa fa-search',
				text: 'Search',
				scope: this,
				listeners: {
					click: 'onCustomSearchButtonClick',
					scope: 'controller'
				}
			}
		];

		this.callParent( arguments);
	},
	
	addCondition: function( type, itemConfig) {
		var theCond = Ext.create( 'LMSplaylistEditor.ux.PanelSearchCustomItem', { itemType: type, initItemConfig: itemConfig });
		theCond.on("removeMe", function( cond, options) {
			this.removeCondition( cond);
		}, this);
		
		this.add( theCond);
		this.allConds.push( theCond);
		this.updateLayout();
		this.down('#tbar-split-addcond').menu.items.items[ type-1].setDisabled( true);;
		return theCond;
	},
	removeCondition: function( theCond) {
		this.remove( theCond);
		this.down('#tbar-split-addcond').menu.items.items[ theCond.itemType-1].setDisabled( false);
		this.allConds.splice( this.allConds.indexOf(theCond), 1);
		this.updateLayout();
	},
	removeAllConditions: function() {
		var me = this;
		Ext.each( this.allConds, function(v) {
			if(v) {
				me.removeCondition( v);
			}
		});
	},
	getSearchParms: function( ) {
		var dbSearchStrings =[];
		var dbAttStrings =[];
		Ext.each( this.allConds, function( v) {
			v.updateDBCondition();
			dbSearchStrings.push(v.dbSearchString);
			dbAttStrings.push(v.dbAttString);
		});
		//dbAttStrings.push( {'order_by': [this.sortBy] });
		
		var args= {
					cmd: (this.searchForTracks)?'getTracksByParams':'getAlbumsByParams',
					player: '',
					dbSearch: dbSearchStrings ,
					dbAtts: dbAttStrings
				};
		return args;
	}
});