Ext.define('LMSplaylistEditor.ux.SlimGridAlbumsBase', {
	extend: 'Ext.grid.Panel',
	requires: [ 'Ext.grid.filters.Filters'],
	sortableColumns: true,
	selModel: {
		selType: 'rowmodel',
		mode: 'MULTI',
		pruneRemoved: false
	},
	plugins: 'gridfilters',
	viewConfig: {
		plugins: {
			ddGroup: 'GridTracksDND',
			ptype: 'gridviewdragdrop',
			dragText: 'Drag items to the \"Add\" button, or drop into the playlist',
			enableDrop: false
		}
	},
	enableDragDrop : true,
	closeAction: 'hide',
	scrollable: 'vertical',

	showYearCol: true,
	showArtistCol: true,
	fractionChars: ['','&frac14;','&frac12;','&frac34;'],
	albumTip: undefined,

	currentArtistId: 0,

	layout: {
		type: "fit"
	},
	
	initComponent: function() {

		this.columns = [
			{ text: '', dataIndex: 'artwork', width: 60, menuDisabled: true, sortable: false, renderer: function( value) {
				return Ext.DomHelper.markup({
					tag : 'img',
					src: LMSplaylistEditor.RuntimeConfig.config.LMSURL+'/music/' + value + '/cover_50x50_o',
					width: 50,
					height: 50
					});
				}
			},{ 
				text: 'Title', dataIndex: 'title', flex:2, renderer: function( value, metaData, record, rowIndex, colIndex, store) {
					return value
							+((!this.showArtistCol && record.get('contributor'))?"<br>"+record.get('contributor'):"")
							+((!this.showYearCol && record.get('year')!=0)?"<br>"+record.get('year'):"")
							+"<br>Duration: " + record.get('duration')
							+((record.get('compilation'))?"<br>(Compilation)":"");
				}
			},{ 
				text: 'Artist', dataIndex: 'contributor', flex: 1, hidden: !this.showArtistCol,
				listeners: {
					hide: {
						fn: function() {
							this.showArtistCol = false;
						},
						scope: this
					},
					show: {
						fn: function() {
							this.showArtistCol = true;
						},
						scope: this
					}
				}

			},{ 
				text: 'Year', dataIndex: 'year', filter:true, width: 60, hidden: !this.showYearCol, renderer: function( value) {
					return (value!=0)?value:"";
				},
				listeners: {
					hide: {
						fn: function() {
							this.showYearCol = false;
						},
						scope: this
					},
					show: {
						fn: function() {
							this.showYearCol = true;
						},
						scope: this
					}
				}
			}
	
		];
/*
		if( LMSplaylistEditor.userconfig.UI_statesave && this.id) {
			this.stateId = this.id;
			this.stateful = true;
		}
*/
		this.callParent( );
	},
	
	
	beforeShow: function() {
		
		this.callParent( arguments);
		var view = this.getView();
		
		if( this.albumTip == undefined) {
			this.albumTip = Ext.create('Ext.tip.ToolTip', {
				target: view.el,
				delegate: view.cellSelector,
				trackMouse: false,
				renderTo: Ext.getBody(),
				maxWidth: 500,
				maxHeight: 500,
				border: false,
				listeners: {
					beforeshow: function updateTipBody(tip) {
						if(tip.triggerElement.cellIndex == 0){
							var record = view.getRecord(tip.triggerElement.parentNode);
							var i = Ext.DomHelper.markup({
								tag: 'img',
								src: LMSplaylistEditor.RuntimeConfig.config.LMSURL+'/music/' + record.get('artwork')+ '/cover',
								width: 500,
								height: 500
								});
							tip.update(i);
						} else {
							return false;
						}
					}
				}
			});
		}
		
	},
	/*
	showCoversWin: function() {
		if( this.getStore().getCount() == 0) {
			return;
		}
		var p = Ext.create('LMSplaylistEditor.ux.SlimPanelAlbumView', {albumStore: this.getStore() });
		var c = this.getStore().getCount()*p.coverSize;
		
		var win = Ext.create('LMSplaylistEditor.ux.InfoWin', {
			title: "Albums",
			modal: false,
			layout: "fit",
			items: p,
			width: (c > Ext.getBody().getViewSize().width)?"95%":"60%"
		});
		win.show();
		var pwh = p.getDVSize();
		var wwh = win.getSize();
		if( pwh.height > wwh.height) {
			win.setHeight(Math.min( Ext.getBody().getViewSize().height, (pwh.height+65)));
			win.center();
		}
	},
	*/
	displayAlbumsStats: function( result) {
		if (!this.albumsStatsTip) {
			this.albumsStatsTip = Ext.create('Ext.tip.ToolTip', {
				title: 'Selected albums statistics',
				draggable: true,
				//minWidth: 500,
				closable: true,
				autoHide: false,
				hideDelay: 1000,
				dismissDelay: 0
			});
		}
		var r=" ";
		if( result.ratingavg) {
			// TODO: replace by Utils.
			var n = Math.floor(result.ratingavg/20);
			for( var i = 0; i < n; i++) {
				r = r + "*";
			}
			r=r+this.fractionChars[ Math.floor( (result.ratingavg-n*20)/5 )];
			r="<br><b>Average rating:</b>"+r+" ("+result.ratingcount+" track(s) rated)";
		}
		this.albumsStatsTip.update("<b>Number of tracks:</b> " + result.count + "<br><b>Duration:</b> " + LMSplaylistEditor.Utils.secsToDuration(result.duration)+r);
		if (!this.albumsStatsTip.isVisible() ) {
			var b = Ext.ComponentManager.get('albumsearchresults-button-info');
			if( b && b.isVisible() ) {
				this.albumsStatsTip.showAt ( b.getPosition());
			} else {
				this.albumsStatsTip.show();
			}
		} else {
			this.albumsStatsTip.setActive( true);
		}
	}
	

});