Ext.define('LMSplaylistEditor.ux.SlimGridTracksBase', {
	extend: 'Ext.grid.Panel',
	requires: ['LMSplaylistEditor.Utils', 'LMSplaylistEditor.RuntimeConfig', 'Ext.grid.filters.Filters'],

	sortableColumns: true,
	selModel: {
		selType: 'rowmodel',
		mode: 'MULTI'
	},
	layout: {
		type: "fit"
	},
	plugins: 'gridfilters',
	viewConfig: {
		plugins: {
			ddGroup: 'GridTracksDND',
			ptype: 'gridviewdragdrop',
			dragText: 'Drag items to the \"Add\" button, or drop into the playlist',
			enableDrop: false
		}
	},
	enableDragDrop : true,
	closeAction: 'hide',
	scrollable: 'vertical',

	showAlbumCol: true,
	showArtistCol: true,
	showRatingsCol: true,

	tip: undefined,

	initComponent: function() {
		this.columns = [
			{ 
				text: '#', dataIndex: 'tracknum', width: 30
			},{ 
				text: 'Name', dataIndex: 'name', flex:2, filter: true
			},{ 
				text: 'Artist', dataIndex: 'artistName', flex:1, filter: true, hidden: !this.showArtistCol
			},{ 
				text: 'Album', dataIndex: 'albumname', flex:1, filter: true, hidden: !this.showAlbumCol
			},{ 
				text: 'Year', dataIndex: 'year', width: 50, filter: true, renderer: function( value, metaData, record, rowIndex, colIndex, store) {
					return (value !=0)?value:"";
				}
			},{ 
				text: 'Time', dataIndex: 'duration', width: 70, align: 'right'
			},{ 
				text: 'Rating', dataIndex: 'rating', width: 60, align: 'center', filter: true, renderer: function( value, metaData, record, rowIndex, colIndex, store) {
					return LMSplaylistEditor.Utils.getPrettyRating(value);
				}
			}
		];
		if( LMSplaylistEditor.RuntimeConfig.config.UI_statesave && this.id) {
			this.stateId = this.id;
			this.stateful = true;
		}
		this.callParent( );
		this.contextMenu = Ext.create( 'LMSplaylistEditor.ux.SlimMenuContextTrackDetail', { grid: this });
		this.on("itemcontextmenu", this.onItemcontextmenu, this);
//		this.beforeShowX();
//		console.log("SlimGridTracksBase initComponent done");
	},

	onItemcontextmenu: function(view, rec, node, index, e) {
			this.contextMenu.setCurrentTrackInfo( rec);
			this.contextMenu.showAt(e.getXY());
			e.stopEvent();
	},
	
	beforeShow: function() {
//		this.callParent( arguments);
		if( this.tip == undefined) {
			var view = this.getView();
			this.tip = Ext.create('Ext.tip.ToolTip', {
				target: view.el,
				delegate: view.itemSelector,
				trackMouse: true,
				dismissDelay: 0,
				width: 'auto',
				listeners: {
					beforeshow: function updateTipBody(tip) {
						var record = view.getRecord(tip.triggerElement);
						if( !record) {
							return;
						}
						var r = "";
						if( record.get('rating')) {
							r= "Rating: "+LMSplaylistEditor.Utils.getPrettyRating( record.get('rating'))+"<br>";
						}
						var u = "";
						if( record.get('url')) {
							try {
								u = "URL: "+(decodeURI( record.get('url'))).replace(/^.*\/\/\//,"/")+"<br>";
							} catch (e) {
								console.log(record.get('url')+":"+e.message);
							}
						}

						
						var t = (record.get('disc')?"Disc: "+record.get('disc')+"<br>":"") 
							+((record.get('genre'))?"Genre: "+record.get('genre')+"<br>":"") 
							+r 
							+((record.get('playcount'))?"Play Count: "+record.get('playcount')+"<br>":'')
							+"Bitrate: "+record.get('prettyBitRate')
							+"<br>File size: "+( LMSplaylistEditor.Utils.bytesToSize( parseInt(record.get('filesize'))) )+"<br>"
							+"File date: "+( LMSplaylistEditor.Utils.dateToString( record.get('timestamp')) )+"<br>"
							+((record.get('replay_gain'))?"Replay Gain: "+record.get('replay_gain')+"<br>":'')
							+((record.get('tagversion'))?"Tag: "+record.get('tagversion')+"<br>":'')
							+u
							+((record.get('comment'))?"Comment: "+record.get('comment')+"<br>":"");
						var i = Ext.DomHelper.markup({
							tag: 'img',
							src: LMSplaylistEditor.RuntimeConfig.config.LMSURL+'/music/' + record.get('coverid') + '/cover_200x200_m',
							width: 200,
							height: 200
							});
							
						tip.update(t+"<div align=\"center\"><br>"+i+"</div>");
					}
				}
			});
		}
	}

});